==> spip_4.0.4.orig.tar.xz: plugins-dist/mots/lang/adminmots_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/adminmots?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_associer' => 'Koppel',
	'bouton_dissocier' => 'Ontkoppel',
	'bouton_fusionner' => 'Samenvoegen',

	// E
	'erreur_admin_mot_action_inconnue' => 'Wat wil je doen?',
	'erreur_mot_cle_deja' => 'Onmogelijk: dit is hetzelfde trefwoord.',
	'erreur_selection_id' => 'Kies een trefwoord of geef zijn ID in het invoerveld aan',

	// I
	'icone_administrer_mot' => 'Geavanceerde handelingen',

	// L
	'label_associer_objets_mot' => '<b>Koppel</b> dit trefwoord aan objecten met het trefwoord',
	'label_confirm_fusion' => 'Deze handeling kan niet worden geannuleerd.<br />
<strong>Dit trefwoord #@id_mot@ wordt verwijderd</strong> en de volgende koppelingen worden aan trefwoord #@id_mot_new@ toegevoegd: ',
	'label_confirm_fusion_check' => 'Controleer de samenvoeging van trefwoord #@id_mot@ met trefwoord #@id_mot_new@',
	'label_dissocier_objets_mot' => '<b>Ontkoppel</b> dit trefwoord van objecten met het trefwoord',
	'label_fusionner_mot' => '<b>Samenvoegen</b> met het trefwoord',
	'label_mot_1_enfant' => 'Kind:',
	'label_mot_nb_enfants' => 'Kinderen:',
	'label_mot_parent' => 'Ouder:',

	// P
	'placeholder_id_mot' => 'of #ID_MOT',
	'placeholder_select' => 'Kies…',

	// R
	'result_associer_nb' => ' zijn aan dit trefwoord gekoppeld',
	'result_associer_ras' => 'Geen actie: alle objecten waren al aan dit trefwoord gekoppeld',
	'result_cancel_ok' => 'Laatste handeling werd geannuleerd.',
	'result_dissocier_nb' => ' werden van dit trefwoord ontkoppeld',
	'result_dissocier_ras' => 'Geen actie: geen van de doelobjecten is aan dit trefwoord gekoppeld',
	'result_fusionner_ok' => 'Je kunt dit trefwoord nu verwijderen: alle koppelingen zijn naar trefwoord @mot@ verplaatst.',

	// T
	'titre_formulaire_administrer_mot' => 'Dit trefwoord beheren'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/mots/lang/adminmots_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/adminmots?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_associer' => 'Koppel',
	'bouton_dissocier' => 'Ontkoppel',
	'bouton_fusionner' => 'Samenvoegen',

	// E
	'erreur_admin_mot_action_inconnue' => 'Wat wil je doen?',
	'erreur_mot_cle_deja' => 'Onmogelijk: dit is hetzelfde trefwoord.',
	'erreur_selection_id' => 'Kies een trefwoord of geef zijn ID in het invoerveld aan',

	// I
	'icone_administrer_mot' => 'Geavanceerde handelingen',

	// L
	'label_associer_objets_mot' => '<b>Koppel</b> dit trefwoord aan objecten met het trefwoord',
	'label_confirm_fusion' => 'Deze handeling kan niet worden geannuleerd.<br />
<strong>Dit trefwoord #@id_mot@ wordt verwijderd</strong> en de volgende koppelingen worden aan trefwoord #@id_mot_new@ toegevoegd: ',
	'label_confirm_fusion_check' => 'Controleer de samenvoeging van trefwoord #@id_mot@ met trefwoord #@id_mot_new@',
	'label_dissocier_objets_mot' => '<b>Ontkoppel</b> dit trefwoord van objecten met het trefwoord',
	'label_fusionner_mot' => '<b>Samenvoegen</b> met het trefwoord',
	'label_mot_1_enfant' => 'Kind:',
	'label_mot_nb_enfants' => 'Kinderen:',
	'label_mot_parent' => 'Ouder:',

	// P
	'placeholder_id_mot' => 'of #ID_MOT',
	'placeholder_select' => 'Kies…',

	// R
	'result_associer_nb' => ' zijn aan dit trefwoord gekoppeld',
	'result_associer_ras' => 'Geen actie: alle objecten waren al aan dit trefwoord gekoppeld',
	'result_cancel_ok' => 'Laatste handeling werd geannuleerd.',
	'result_dissocier_nb' => ' werden van dit trefwoord ontkoppeld',
	'result_dissocier_ras' => 'Geen actie: geen van de doelobjecten is aan dit trefwoord gekoppeld',
	'result_fusionner_ok' => 'Je kunt dit trefwoord nu verwijderen: alle koppelingen zijn naar trefwoord @mot@ verplaatst.',

	// T
	'titre_formulaire_administrer_mot' => 'Dit trefwoord beheren',
];
